@@ -1,21 +1,22 @@
 package Finance::Bank::ID::Mandiri;
 
-our $DATE = '2019-05-13'; # DATE
-our $VERSION = '0.382'; # VERSION
-
 use 5.010001;
-
-use Moo;
-
+use strict;
+use warnings;
 use HTTP::Headers;
-use HTTP::Headers::Patch::DontUseStorable -load_target=>0;
 use Parse::Number::EN qw(parse_number_en);
 
+use Moo;
 extends 'Finance::Bank::ID::Base';
 
 has _variant => (is => 'rw');
 has _re_tx   => (is => 'rw');
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-08-26'; # DATE
+our $DIST = 'Finance-Bank-ID-Mandiri'; # DIST
+our $VERSION = '0.383'; # VERSION
+
 my $re_acc         = qr/(?:\d{13})/;
 my $re_currency    = qr/(?:\w{3})/;
 my $re_money       = qr/(?:\d+(?:\.\d\d?)?)/;
@@ -687,7 +688,7 @@ Finance::Bank::ID::Mandiri - Check your Bank Mandiri accounts from Perl
 
 =head1 VERSION
 
-This document describes version 0.382 of Finance::Bank::ID::Mandiri (from Perl distribution Finance-Bank-ID-Mandiri), released on 2019-05-13.
+This document describes version 0.383 of Finance::Bank::ID::Mandiri (from Perl distribution Finance-Bank-ID-Mandiri), released on 2021-08-26.
 
 =head1 SYNOPSIS
 
@@ -965,6 +966,50 @@ Please visit the project's homepage at L<https://metacpan.org/release/Finance-Ba
 
 Source repository is at L<https://github.com/perlancar/perl-Finance-Bank-ID-Mandiri>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTORS
+
+=for stopwords Steven Haryanto (on PC)
+
+=over 4
+
+=item *
+
+Steven Haryanto (on PC) <stevenharyanto@gmail.com>
+
+=item *
+
+Steven Haryanto <steven@masterweb.net>
+
+=back
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2021, 2019, 2017, 2016, 2015, 2014, 2013, 2012, 2011, 2010 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Finance-Bank-ID-Mandiri>
@@ -973,15 +1018,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2019, 2017, 2016, 2015, 2014, 2013, 2012, 2011, 2010 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
